# Ersilia's LazyQSAR

A library to build supervised models for chemistry fastly.

## Installation

Install LazyQSAR from source:

```bash
git clone https://github.com/ersilia-os/lazy-qsar.git
cd lazy-qsar
python -m pip install -e .
```

To use the default Lazy QSAR descriptors, please install them:
```bash
python -m pip install -e .[descriptors]
```

And to use a light version of [TuneTables](https://github.com/ersilia-os/TuneTablesLight/tree/main) as an estimator, also please install it:
```bash
pip install "lazyqsar[tune-tables]"
pip install "git+https://github.com/ersilia-os/TuneTablesLight.git@main"
```

## Binary Classification

LazyQSAR's binary classifier can run either with default descriptors or with custom descriptors passed by the user.

### Built-in descriptors

Instantiate the LazyBinaryQSAR class with either of the available descriptors (Chemeleon or Morgan fingerprints) and estimators (Logistic Regression, Random Forest or Tune Tables) and simply fit and predict results:

```python
import lazyqsar

model = lazyqsar.LazyBinaryQSAR(
    descriptor_type="chemeleon", model_type="logistic_regression"
    )
model.fit(smiles_train, y_train)
model.save_model(model_path)
y_hat = model.predict_proba(smiles_test)
```

### Custom-made descriptors
Pre-calculate your descriptors using the preferred method. We recommend using the [Ersilia Model Hub](https://github.com/ersilia-os/ersilia) to that end. The `.h5` format generated by Ersilia can be directly passed to the LazyQSAR pipeline, or, alternatively, an array with the descriptors.

```python
import lazyqsar

X_train = "my_descriptors" #path to descriptors
X_test = "my_descriptors" #path to descriptors

 model = lazyqsar.LazyBinaryClassifier(
    model_type="logistic_regression"
    )
model.fit(X_train, y_train)
model.save_model(model_path)
y_hat = model.predict_proba(X_test)
```

## Tests and benchmarks

In the `/benchmark` folder you will find the performance of the default estimators and descriptors on the TDCommons ADMET dataset. In the `/tests` folder you can find a quick implementation of the methods described for easily checking any change in the code. The Bioavailability dataset is used as an example. 

## Disclaimer

This library is only intended for quick-and-dirty QSAR modeling. For a more complete automated QSAR modeling, please refer to [Zaira Chem](https://github.com/ersilia-os/zaira-chem)

## About us

Learn about the [Ersilia Open Source Initiative](https://ersilia.io)!
